@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
 {
-  $Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '3.202';
+  $Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '3.203';
 }
 BEGIN {
   $Dist::Zilla::PluginBundle::Author::RWSTAUNER::AUTHORITY = 'cpan:RWSTAUNER';
@@ -25,6 +25,7 @@ use Dist::Zilla 4.200005;
 with qw(
   Dist::Zilla::Role::PluginBundle::Easy
   Dist::Zilla::Role::PluginBundle::Config::Slicer
+  Dist::Zilla::Role::PluginBundle::PluginRemover
 );
 # Dist::Zilla::Role::DynamicConfig is not necessary: payload is already dynamic
 
@@ -386,7 +387,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 3.202
+version 3.203
 
 =head1 SYNOPSIS
 
@@ -450,15 +451,24 @@ as it is included by the Bundle.
 
 See L<Config::MVP::Slicer/CONFIGURATION SYNTAX> for more information.
 
-If your situation is more complicated you can use the C<skip_plugins>
-attribute to have the Bundle ignore that plugin
+If your situation is more complicated you can use the C<-remove> attribute
+(courtesy of L<Dist::Zilla::Role::PluginBundle::PluginRemover>)
+to have the Bundle ignore that plugin
 and then you can add it yourself:
 
   [MetaNoIndex]
   directory = one-dir
   directory = another-dir
   [@Author::RWSTAUNER]
-  skip_plugins = MetaNoIndex
+  -remove = MetaNoIndex
+
+C<-remove> can be specified multiple times.
+
+Alternatively you can use the C<skip_plugins> attribute (only once)
+which is a regular expression that matches plugin name or package.
+
+  [@Author::RWSTAUNER]
+  skip_plugins = MetaNoIndex|SomethingElse
 
 =head1 EQUIVALENT F<dist.ini>
 
@@ -569,6 +579,10 @@ L<Dist::Zilla::Role::PluginBundle::Config::Slicer>
 
 =item *
 
+L<Dist::Zilla::Role::PluginBundle::PluginRemover>
+
+=item *
+
 L<Pod::Weaver>
 
 =back
